package com.landray.kmss.plugin.util;

import com.landray.kmss.plugin.util.FileUtil;
import com.landray.kmss.plugin.util.StringUtil;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class MD5Util {

   private static final Logger logger = LogManager.getLogger(MD5Util.class);
   protected static char[] hexDigits = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
   protected static MessageDigest messagedigest = null;


   public static String getMD5String(String s) {
      return getMD5String((byte[])s.getBytes());
   }

   public static String getMD5String(File file) throws IOException {
      if(file.exists() && !file.isDirectory()) {
         FileInputStream fis = new FileInputStream(file);
         String result = getMD5String((InputStream)fis);
         fis.close();
         return result;
      } else {
         return "";
      }
   }

   public static String getMD5String(InputStream in) throws IOException {
      byte[] buffer = new byte[65536];
      boolean numRead = false;

      int numRead1;
      while((numRead1 = in.read(buffer)) > 0) {
         messagedigest.update(buffer, 0, numRead1);
      }

      return bufferToHex(messagedigest.digest());
   }

   public static String getMD5String(byte[] bytes) {
      messagedigest.update(bytes);
      return bufferToHex(messagedigest.digest());
   }

   private static String bufferToHex(byte[] bytes) {
      return bufferToHex(bytes, 0, bytes.length);
   }

   private static String bufferToHex(byte[] bytes, int m, int n) {
      StringBuffer stringbuffer = new StringBuffer(2 * n);
      int k = m + n;

      for(int l = m; l < k; ++l) {
         appendHexPair(bytes[l], stringbuffer);
      }

      return stringbuffer.toString();
   }

   private static void appendHexPair(byte bt, StringBuffer stringbuffer) {
      char c0 = hexDigits[(bt & 240) >> 4];
      char c1 = hexDigits[bt & 15];
      stringbuffer.append(c0);
      stringbuffer.append(c1);
   }

   public static Map getFilesMd5(String basePath, String filePath) {
      HashMap Md5 = new HashMap();

      try {
         File e = new File(filePath);
         if(e.exists()) {
            if(e.isDirectory()) {
               String[] filelist = e.list();

               for(int i = 0; i < filelist.length; ++i) {
                  File fileC = new File(filePath + File.separator + filelist[i]);
                  if(fileC.isDirectory()) {
                     Map tmpPath = getFilesMd5(basePath, fileC.getPath());
                     Iterator var8 = tmpPath.keySet().iterator();

                     while(var8.hasNext()) {
                        String key = (String)var8.next();
                        Md5.put(key, (String)tmpPath.get(key));
                     }
                  } else {
                     String var11 = fileC.getPath().replace(basePath + File.separator, "");
                     var11 = var11.replace("\\", "/");
                     Md5.put(var11, getMD5String((File)fileC));
                  }
               }
            }

            Md5.put(e.getPath(), getMD5String((File)e));
         }
      } catch (Exception var10) {
         var10.printStackTrace();
      }

      return Md5;
   }

   public static boolean checkFilesMd5(String localPath, String remotePath) throws Exception {
      Map localPathMd5Map = FileUtil.getFilesMd5((String)localPath, localPath);
      Map remotePathMd5Map = FileUtil.getFilesMd5((String)remotePath, remotePath);
      if(localPathMd5Map != null && !localPathMd5Map.isEmpty()) {
         if(localPathMd5Map != null && !localPathMd5Map.isEmpty()) {
            Iterator var4 = localPathMd5Map.keySet().iterator();

            String keylocal;
            do {
               if(!var4.hasNext()) {
                  return true;
               }

               keylocal = (String)var4.next();
               if(!remotePathMd5Map.containsKey(keylocal)) {
                  return false;
               }
            } while(StringUtil.isNull((String)localPathMd5Map.get(keylocal)) || StringUtil.isNull((String)remotePathMd5Map.get(keylocal)) || ((String)localPathMd5Map.get(keylocal)).equals(remotePathMd5Map.get(keylocal)));

            return false;
         } else {
            return false;
         }
      } else {
         return true;
      }
   }

   public static void main(String[] args) throws IOException {
      String filePath = "D:\\test\\SPRJ20211126_YLSW\\zxfwq-master\\zxfwq-master/WebContent/kms/knowledge/kms_knowledge_index_ui/kmsKnowledge_index_cat.jsp";
      String filePath2 = "D:/test/SPRJ20211126_YLSW/ekp/WebContent/kms/knowledge/kms_knowledge_index_ui/kmsKnowledge_index_cat.jsp";
      System.out.println("filePath=" + filePath);
      System.out.println("MD5=" + getMD5String((File)(new File(filePath))));
      System.out.println("filePath2=" + filePath2);
      System.out.println("MD5=" + getMD5String((File)(new File(filePath2))));
   }

   static {
      try {
         messagedigest = MessageDigest.getInstance("MD5");
      } catch (NoSuchAlgorithmException var1) {
         logger.error(MD5Util.class.getName() + "初始化失败，MessageDigest不支持MD5Util。");
      }

   }
}
